@@ -102,6 +102,31 @@ bool script::checks::isValue(const char *text)
 	}
 }
 
+const char *script::checks::chkApply(script *img, script::header *scr, script::line_t *line)
+{
+	if(line->argc < 1)
+		return "template define script required";
+
+	if(line->argc > 1)
+		return "only one template define can be applied";
+
+	if(scr->first) 
+		return "apply must be first statement of a new script";
+
+	if(scr->events)
+		return "only one apply statement can be used";
+
+	if(!isalnum(line->argv[0][0]))
+		return "must apply using valid name of a defined script";
+
+	script::header *tmp = script::find(img, line->argv[0]);
+	if(!tmp)
+		return "invalid or unknown script applied";
+
+	scr->events = tmp->events;
+	return NULL;
+}
+
 const char *script::checks::chkContinue(script *img, script::header *scr, script::line_t *line)
 {
 	method_t method = img->looping();
