@@ -331,6 +331,7 @@ void script::init(void)
 		{"else", (method_t)&methods::scrElse, (check_t)&checks::chkElse},
 		{"endif", (method_t)&methods::scrEndif, (check_t)&checks::chkEndif},
 		{"strict", (method_t)NULL, (check_t)&checks::chkStrict},
+		{"apply", (method_t)NULL, (check_t)&checks::chkApply},
 		{"_ifthen", (method_t)&methods::scrWhen, (check_t)&checks::chkWhen},
 		{"_define", (method_t)&methods::scrDefine, (check_t)&checks::chkDefine},
 		{"_invoke", (method_t)&methods::scrInvoke, (check_t)&checks::chkInvoke},
@@ -383,6 +384,7 @@ script *script::compile(const char *fn, script *cfg)
 	script::header *invoke;
 	bool define = false;
 	bool when = false;
+	bool label = false;
 	unsigned pos;
 	const char *cp;
 
@@ -423,7 +425,7 @@ initial:
 	if(!img->first)
 		img->first = scr;
 
-	while(when || define || String::getline(fp, buffer)) {
+	while(when || label || define || String::getline(fp, buffer)) {
 		if(define) {
 			indented = true;
 			goto parse;
@@ -435,6 +437,15 @@ initial:
 			goto parse;
 		}
 
+		if(label) {
+			label = false;
+			indented = true;
+			token = String::token(NULL, &tokens, " \t", "{}\'\'\"\"");
+			if(!token)
+				continue;
+			goto parse;
+		}
+
 		indented = false;
 		tokens = buffer.c_mem();
 		if(isspace(*tokens)) {
@@ -473,9 +484,26 @@ initial:
 		if(*token == '@') {
 			section = true;
 			name = token;
+			label = true;
 			goto closure;
 		}	
 
+		if(String::equal(token, "template")) {
+			if(section) {
+				img->errlog(lnum, "templates must be before named sections");
+				continue;
+			}
+			if(indented) {
+				img->errlog(lnum, "templates cannot be indented");
+				continue;
+			}
+			token = String::token(NULL, &tokens, " \t", "{}\'\'\"\"");
+			if(!token)
+				img->errlog(lnum, "template must be named");
+			name = token;
+			goto closure;
+		}
+
 		if(String::equal(token, "define")) {
 			if(section) {
 				img->errlog(lnum, "defines must be before named sections");
@@ -491,7 +519,6 @@ initial:
 				img->errlog(lnum, "cannot redefine existing command");
 				continue;
 			}
-			section = true;
 			define = true;
 			name = token;
 			goto closure;
@@ -642,7 +669,6 @@ closure:
 //		sp.next();
 //	}
 
-
 	if(!feof(fp))		
 		goto initial;
 
