@@ -705,7 +705,7 @@ bool script::interp::scriptEvent(const char *name)
 		while(stackp > stack[stackp].base && stack[stackp].line->loop)
 			--stackp;
 
-		if(stackp >= stack[stackp].base)
+		if(stackp && stackp >= stack[stackp].base)
 			--stackp;
 		else
 			return false;
@@ -799,6 +799,12 @@ bool script::interp::trylabel(const char *label)
 
 bool script::interp::tryexit(void)
 {
+	if(stack[frame].event && String::equal("exit", stack[frame].event->name))
+		return false;
+
+	if(scriptEvent("exit"))
+		return true;
+
 	script::header *ex = script::find(image.get(), "@exit");
 	frame = 0;
 
